@@ -36,12 +36,12 @@ grVizToPNG <- function (g, width=NULL, height=NULL, folder = ".",filename) {
     filename <- paste0(sapply(as.list(substitute({g})[-1]), deparse),".png")
   }
   if (is.null(g)) {
-    g <- DiagrammeR::grViz("digraph empty{ Node1[label='Empty'] }")
+    g <- format(DiagrammeR::grViz("digraph empty{ Node1[label='Empty'] }"))
   }
   # Convert any double backslashes to forward slashes.
   folder <- gsub("\\\\","/",folder)
   fullpath <- file.path(folder,filename)
-  message <- utils::capture.output(svg <- DiagrammeRsvg::export_svg(g))
+  message <- utils::capture.output(svg <- format(DiagrammeRsvg::export_svg(g)))
   result <- rsvg::rsvg_png(charToRaw(svg),fullpath, width = width, height=height)
   invisible(fullpath)
 }
